# Telliot Feeds

This package contains reporting tools and datafeeds for Tellor oracles.

## [Project documentation](https://tellor-io.github.io/telliot-feeds/)

## [Installation and Configuration](https://tellor-io.github.io/telliot-feeds/getting-started/)

## [Usage](https://tellor-io.github.io/telliot-feeds/usage/)

## Example

Report using the CLI:
```
telliot-feeds -a fakeaccountname report
```
